==> patch-2.2.26.zip: app/views/report/userMigration.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('migration')?>"><?=Language::show('userMigration', 'report')?></a></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="ReportController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak">
            <div class="row">
                <span class="csrf_token hide"><?=$data['csrf_token']?></span>
                <span class="currentPage hide"><?='userMigration'?></span>
                <div class="panel">
                    <div class="panel-heading"><h3><?=$data['crumb1']?></div>
                    <div class="panel-body">
                        <div class="h4 loading text-center" style="display: none;">Loading.....</div>
                        <a ng-click="exportToExcel('#UserMigration', 'User Migration', userMigration)" class="btn btn-default">Export To excel</a>
                        <br/><br/>
                        <table id="UserMigration" class="table table-bordered userMigration" style="display: none;">
                            <thead>
                            <tr>
                                <th class="text-center clickAble" ng-click="sortType = 'userName'; sortReverse = !sortReverse">
                                    <?=Language::show('user', 'keywords')?>
                                    <span ng-show="sortType == 'userName' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortType == 'userName' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                                <th class="text-center clickAble" ng-click="sortType = 'emailId'; sortReverse = !sortReverse">
                                    <?=Language::show('email', 'keywords')?>
                                    <span ng-show="sortType == 'emailId' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortType == 'emailId' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                                <th class="text-center clickAble" ng-click="sortType = 'createdTimestamp'; sortReverse = !sortReverse">
                                    <?=Language::show('Migrated Time', 'keywords')?>
                                    <span ng-show="sortType == 'createdTimestamp' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortType == 'createdTimestamp' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                                <th class="text-center clickAble" ng-click="sortType = 'migratedBy'; sortReverse = !sortReverse">
                                    <?=Language::show('Migrated By', 'keywords')?>
                                    <span ng-show="sortType == 'migratedBy' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortType == 'migratedBy' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                            </tr>
                            </thead>
                            <tbody>
                            <tr ng-repeat="value in userMigration | orderBy:sortType:sortReverse" class="text-center">
                                <td class="text-center" ng-cloak>{{ value.userName }}</td>
                                <td class="text-center" ng-cloak>{{ value.emailId }}</td>
                                <td class="text-center" ng-cloak>{{ value.createdTimestamp }}</td>
                                <td class="text-center" ng-cloak>{{ value.migratedBy }}</td>
                            </tr>
                            </tbody>
                        </table>
                        <div class="h4 userMigrationError text-center" style="display: none">There was not details found for Failed Backup</div>
                    </div>
                    <div class="row loadMore" style="display: none;">
                        <div class="col-lg-12 text-center">
                            <a class="loadMoreBtn btn btn-primary" ng-click="loadMore(skipValue, 'userMigration')">Load More ...</a>
                            <br /><br />
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script>
    $('.timePicker').timepicker({
        showMeridian: false,
        defaultTime: '9:45'
    });
</script>
<script src="<?=Url::templatePath()?>js/angular/controllers/ReportController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>

==> patch-2.3.5.0.zip: app/views/report/userMigration.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('migration')?>"><?=Language::show('userMigration', 'report')?></a></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="ReportController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak">
            <div class="row">
                <span class="csrf_token hide"><?=$data['csrf_token']?></span>
                <span class="currentPage hide"><?='userMigration'?></span>
                <div class="panel">
                    <div class="panel-heading"><h3><?=$data['crumb1']?></div>
                    <div class="panel-body">
                        <div class="h4 loading text-center" style="display: none;">Loading.....</div>
                        <a ng-click="exportToExcel('#UserMigration', 'User Migration', userMigration)" class="btn btn-default">Export To excel</a>
                        <br/><br/>
                        <table id="UserMigration" class="table table-bordered userMigration" style="display: none;">
                            <thead>
                            <tr>
                                <th class="text-center clickAble" ng-click="sortTypeMigration = 'userName'; sortReverse = !sortReverse">
                                    <?=Language::show('userId', 'keywords')?>
                                    <span ng-show="sortTypeMigration == 'userName' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortTypeMigration == 'userName' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                                <th class="text-center clickAble" ng-click="sortTypeMigration = 'emailId'; sortReverse = !sortReverse">
                                    <?=Language::show('email', 'keywords')?>
                                    <span ng-show="sortTypeMigration == 'emailId' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortTypeMigration == 'emailId' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                                <th class="text-center clickAble" ng-click="sortTypeMigration = 'createdTimestamp'; sortReverse = !sortReverse">
                                    <?=Language::show('Migrated Time', 'keywords')?>
                                    <span ng-show="sortTypeMigration == 'createdTimestamp' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortTypeMigration == 'createdTimestamp' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                                <th class="text-center clickAble" ng-click="sortTypeMigration = 'migratedBy'; sortReverse = !sortReverse">
                                    <?=Language::show('Migrated By', 'keywords')?>
                                    <span ng-show="sortTypeMigration == 'migratedBy' && !sortReverse" class="fa fa-caret-up"></span>
                                    <span ng-show="sortTypeMigration == 'migratedBy' && sortReverse" class="fa fa-caret-down"></span>
                                </th>
                            </tr>
                            </thead>
                            <tbody>
                            <tr ng-repeat="value in userMigration | orderBy:sortTypeMigration:sortReverse" class="text-center">
                                <td class="text-center" ng-cloak>{{ value.userName }}</td>
                                <td class="text-center" ng-cloak>{{ value.emailId }}</td>
                                <td class="text-center" ng-cloak>{{ value.createdTimestamp }}</td>
                                <td class="text-center" ng-cloak>{{ value.migratedBy }}</td>
                            </tr>
                            </tbody>
                        </table>
                        <div class="h4 userMigrationError text-center" style="display: none">There was not details found for Failed Backup</div>
                    </div>
                    <div class="row loadMore" style="display: none;">
                        <div class="col-lg-12 text-center">
                            <a class="loadMoreBtn btn btn-primary" ng-click="loadMore(skipValue, 'userMigration')">Load More ...</a>
                            <br /><br />
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script>
    $('.timePicker').timepicker({
        showMeridian: false,
        defaultTime: '9:45'
    });
</script>
<script src="<?=Url::templatePath()?>js/angular/controllers/ReportController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
